pref("imagezoom.autocenter", true);
pref("imagezoom.mmCustomDim", false);
pref("imagezoom.mmCustomZoom", false);
pref("imagezoom.mmFitWindow", false);
pref("imagezoom.mmReset", false);
pref("imagezoom.mmZoomIO", false);
pref("imagezoom.mmZoomPcts", false);
pref("imagezoom.usescroll", true);
pref("imagezoom.triggerbutton", 3);
pref("imagezoom.imagefitbutton", 1);
pref("imagezoom.imageresetbutton", 2);
pref("imagezoom.scrollvalue", 5);
pref("imagezoom.smCustomDim", true);
pref("imagezoom.smCustomZoom", true);
pref("imagezoom.smFitWindow", true);
pref("imagezoom.smReset", true);
pref("imagezoom.smZoomIO", true);
pref("imagezoom.smZoomPcts", true);
pref("imagezoom.zoomvalue", 200);
pref("imagezoom.version", "0.0.0");
pref("imagezoom.reversescrollzoom", false);
pref("imagezoom.scrollmode", 0);
pref("imagezoom.showViewMenu", true);
pref("imagezoom.defaultGlobalZoom", "100");
pref("imagezoom.scrollZoomMode", 0);
pref("imagezoom.autofitlargeimage", false);
pref("imagezoom.showAutoFitInMenu", true);
pref("extensions.{1A2D0EC4-75F5-4c91-89C4-3656F6E44B68}.description", "chrome://imagezoom/locale/imageZoom.properties");
